.. networking-ovn documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. the main title comes from README.rst

.. include:: ../../README.rst

Contents
--------

.. toctree::
   :maxdepth: 2

   admin/index
   install/index
   configuration/index
   contributor/index

.. rubric:: Indices and tables

* :ref:`genindex`
* :ref:`search`

